KeychainEntry

Struct KeychainEntry 

pub struct KeychainEntry { /* private fields */ }
Typed generic-password keychain entry identified by (account, service).

Implementations

Source

impl KeychainEntry

pub fn new(account: impl Into<String>, service: impl Into<String>) -> Self

Create a typed generic-password keychain entry.

pub fn account(&self) -> &str

Account name stored in the keychain item.

pub fn service(&self) -> &str

Service name stored in the keychain item.

pub fn set(&self, password: &str) -> Result<()>

Upsert the password for this keychain entry.

Errors

Returns an error if Security.framework rejects the item or the strings contain NUL bytes.

pub fn get(&self) -> Result<String>

Fetch the password for this keychain entry.

Errors

Returns an error if the item does not exist or Security.framework rejects the query.

pub fn delete(&self) -> Result<()>

Delete this keychain entry.

Errors

Returns an error if Security.framework rejects the delete request.