pub struct ChangePin {
pub pin: RawPin,
pub seed: Option<Seed>,
pub pin_entry: PinEntryMode,
}Fields
pin: RawPinseed: Option<Seed>pin_entry: PinEntryModeTrait Implementations
Sourceimpl Archive for ChangePin
impl Archive for ChangePin
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedChangePin
type Archived = ArchivedChangePin
The archived representation of this type. Read more
Sourcetype Resolver = ChangePinResolver
type Resolver = ChangePinResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for ChangePin
impl BlockingArchive for ChangePin
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ChangePin, __D> for Archived<ChangePin>where
RawPin: Archive,
<RawPin as Archive>::Archived: Deserialize<RawPin, __D>,
Option<Seed>: Archive,
<Option<Seed> as Archive>::Archived: Deserialize<Option<Seed>, __D>,
PinEntryMode: Archive,
<PinEntryMode as Archive>::Archived: Deserialize<PinEntryMode, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ChangePin, __D> for Archived<ChangePin>where
RawPin: Archive,
<RawPin as Archive>::Archived: Deserialize<RawPin, __D>,
Option<Seed>: Archive,
<Option<Seed> as Archive>::Archived: Deserialize<Option<Seed>, __D>,
PinEntryMode: Archive,
<PinEntryMode as Archive>::Archived: Deserialize<PinEntryMode, __D>,