pub struct ComputeSeedFingerprint(pub Seed);Tuple Fields
0: SeedTrait Implementations
Sourceimpl Archive for ComputeSeedFingerprintwhere
Seed: Archive,
impl Archive for ComputeSeedFingerprintwhere
Seed: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedComputeSeedFingerprint
type Archived = ArchivedComputeSeedFingerprint
The archived representation of this type. Read more
Sourcetype Resolver = ComputeSeedFingerprintResolver
type Resolver = ComputeSeedFingerprintResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ComputeSeedFingerprint
impl Clone for ComputeSeedFingerprint
Sourcefn clone(&self) -> ComputeSeedFingerprint
fn clone(&self) -> ComputeSeedFingerprint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<__D: Fallible + ?Sized> Deserialize<ComputeSeedFingerprint, __D> for Archived<ComputeSeedFingerprint>
impl<__D: Fallible + ?Sized> Deserialize<ComputeSeedFingerprint, __D> for Archived<ComputeSeedFingerprint>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ComputeSeedFingerprint, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ComputeSeedFingerprint, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl Drop for ComputeSeedFingerprint
impl Drop for ComputeSeedFingerprint
Sourceimpl MessageId for ComputeSeedFingerprint
impl MessageId for ComputeSeedFingerprint
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for ComputeSeedFingerprintwhere
Seed: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for ComputeSeedFingerprintwhere
Seed: Serialize<__S>,