pub struct GetAppSeed;Trait Implementations
Sourceimpl Archive for GetAppSeed
impl Archive for GetAppSeed
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetAppSeed
type Archived = ArchivedGetAppSeed
The archived representation of this type. Read more
Sourcetype Resolver = GetAppSeedResolver
type Resolver = GetAppSeedResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetAppSeed
impl BlockingArchive for GetAppSeed
Sourceimpl Debug for GetAppSeed
impl Debug for GetAppSeed
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetAppSeed, __D> for Archived<GetAppSeed>
impl<__D: Fallible + ?Sized> Deserialize<GetAppSeed, __D> for Archived<GetAppSeed>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetAppSeed, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetAppSeed, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetAppSeed
impl MessageId for GetAppSeed