pub struct GetDeviceId;Trait Implementations
Sourceimpl Archive for GetDeviceId
impl Archive for GetDeviceId
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetDeviceId
type Archived = ArchivedGetDeviceId
The archived representation of this type. Read more
Sourcetype Resolver = GetDeviceIdResolver
type Resolver = GetDeviceIdResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetDeviceId
impl BlockingArchive for GetDeviceId
Sourceimpl Debug for GetDeviceId
impl Debug for GetDeviceId
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetDeviceId, __D> for Archived<GetDeviceId>
impl<__D: Fallible + ?Sized> Deserialize<GetDeviceId, __D> for Archived<GetDeviceId>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetDeviceId, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetDeviceId, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetDeviceId
impl MessageId for GetDeviceId