pub struct GetFidoPubkey;Trait Implementations
Sourceimpl Archive for GetFidoPubkey
impl Archive for GetFidoPubkey
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetFidoPubkey
type Archived = ArchivedGetFidoPubkey
The archived representation of this type. Read more
Sourcetype Resolver = GetFidoPubkeyResolver
type Resolver = GetFidoPubkeyResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetFidoPubkey
impl BlockingArchive for GetFidoPubkey
Sourceimpl Debug for GetFidoPubkey
impl Debug for GetFidoPubkey
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetFidoPubkey, __D> for Archived<GetFidoPubkey>
impl<__D: Fallible + ?Sized> Deserialize<GetFidoPubkey, __D> for Archived<GetFidoPubkey>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetFidoPubkey, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetFidoPubkey, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetFidoPubkey
impl MessageId for GetFidoPubkey