pub struct GetFirmwareTimestamp;Trait Implementations
Sourceimpl Archive for GetFirmwareTimestamp
impl Archive for GetFirmwareTimestamp
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetFirmwareTimestamp
type Archived = ArchivedGetFirmwareTimestamp
The archived representation of this type. Read more
Sourcetype Resolver = GetFirmwareTimestampResolver
type Resolver = GetFirmwareTimestampResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetFirmwareTimestamp
impl BlockingArchive for GetFirmwareTimestamp
Sourcetype Response = Result<FirmwareTimestamp, AccessDenied>
type Response = Result<FirmwareTimestamp, AccessDenied>
response type for this message
Sourceimpl Debug for GetFirmwareTimestamp
impl Debug for GetFirmwareTimestamp
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetFirmwareTimestamp, __D> for Archived<GetFirmwareTimestamp>
impl<__D: Fallible + ?Sized> Deserialize<GetFirmwareTimestamp, __D> for Archived<GetFirmwareTimestamp>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetFirmwareTimestamp, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetFirmwareTimestamp, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetFirmwareTimestamp
impl MessageId for GetFirmwareTimestamp