pub struct GetOsVersionInfo;Trait Implementations
Sourceimpl Archive for GetOsVersionInfo
impl Archive for GetOsVersionInfo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetOsVersionInfo
type Archived = ArchivedGetOsVersionInfo
The archived representation of this type. Read more
Sourcetype Resolver = GetOsVersionInfoResolver
type Resolver = GetOsVersionInfoResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetOsVersionInfo
impl BlockingArchive for GetOsVersionInfo
Sourcetype Response = Result<Option<OsVersionInfo>, AccessDenied>
type Response = Result<Option<OsVersionInfo>, AccessDenied>
response type for this message
Sourceimpl Debug for GetOsVersionInfo
impl Debug for GetOsVersionInfo
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetOsVersionInfo, __D> for Archived<GetOsVersionInfo>
impl<__D: Fallible + ?Sized> Deserialize<GetOsVersionInfo, __D> for Archived<GetOsVersionInfo>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetOsVersionInfo, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetOsVersionInfo, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetOsVersionInfo
impl MessageId for GetOsVersionInfo