pub struct GetPinEntryMode;Trait Implementations
Sourceimpl Archive for GetPinEntryMode
impl Archive for GetPinEntryMode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetPinEntryMode
type Archived = ArchivedGetPinEntryMode
The archived representation of this type. Read more
Sourcetype Resolver = GetPinEntryModeResolver
type Resolver = GetPinEntryModeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetPinEntryMode
impl BlockingArchive for GetPinEntryMode
Sourcetype Response = PinEntryMode
type Response = PinEntryMode
response type for this message
Sourceimpl Debug for GetPinEntryMode
impl Debug for GetPinEntryMode
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetPinEntryMode, __D> for Archived<GetPinEntryMode>
impl<__D: Fallible + ?Sized> Deserialize<GetPinEntryMode, __D> for Archived<GetPinEntryMode>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetPinEntryMode, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetPinEntryMode, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetPinEntryMode
impl MessageId for GetPinEntryMode