pub struct GetSeed;Trait Implementations
Sourceimpl Archive for GetSeed
impl Archive for GetSeed
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetSeed
type Archived = ArchivedGetSeed
The archived representation of this type. Read more
Sourcetype Resolver = GetSeedResolver
type Resolver = GetSeedResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetSeed
impl BlockingArchive for GetSeed