pub struct KeycardAuthenticityMac(pub [u8; 32]);Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl Archive for KeycardAuthenticityMac
impl Archive for KeycardAuthenticityMac
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedKeycardAuthenticityMac
type Archived = ArchivedKeycardAuthenticityMac
The archived representation of this type. Read more
Sourcetype Resolver = KeycardAuthenticityMacResolver
type Resolver = KeycardAuthenticityMacResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for KeycardAuthenticityMac
impl Debug for KeycardAuthenticityMac
Sourceimpl<__D: Fallible + ?Sized> Deserialize<KeycardAuthenticityMac, __D> for Archived<KeycardAuthenticityMac>
impl<__D: Fallible + ?Sized> Deserialize<KeycardAuthenticityMac, __D> for Archived<KeycardAuthenticityMac>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<KeycardAuthenticityMac, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<KeycardAuthenticityMac, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for KeycardAuthenticityMac
impl MessageId for KeycardAuthenticityMac
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for KeycardAuthenticityMac
impl<__S: Fallible + ?Sized> Serialize<__S> for KeycardAuthenticityMac