pub struct Lockout {
pub lockout_options: LockoutOptions,
pub reboot: bool,
}Fields
lockout_options: LockoutOptionsreboot: boolTrait Implementations
Sourceimpl Archive for Lockoutwhere
LockoutOptions: Archive,
bool: Archive,
impl Archive for Lockoutwhere
LockoutOptions: Archive,
bool: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedLockout
type Archived = ArchivedLockout
The archived representation of this type. Read more
Sourcetype Resolver = LockoutResolver
type Resolver = LockoutResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for Lockout
impl BlockingArchive for Lockout
Sourceimpl<__D: Fallible + ?Sized> Deserialize<Lockout, __D> for Archived<Lockout>where
LockoutOptions: Archive,
<LockoutOptions as Archive>::Archived: Deserialize<LockoutOptions, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
impl<__D: Fallible + ?Sized> Deserialize<Lockout, __D> for Archived<Lockout>where
LockoutOptions: Archive,
<LockoutOptions as Archive>::Archived: Deserialize<LockoutOptions, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,