pub struct RawPin(pub String);Tuple Fields
0: StringTrait Implementations
Sourceimpl Archive for RawPinwhere
String: Archive,
impl Archive for RawPinwhere
String: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRawPin
type Archived = ArchivedRawPin
The archived representation of this type. Read more
Sourcetype Resolver = RawPinResolver
type Resolver = RawPinResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.