ScChallenge

Struct ScChallenge 

pub struct ScChallenge(pub [u8; 104]);
A message sent from the server to the device. Includes the intermediate challenge, deadline and the server signature, in the following binary format:

------------------------------------
| challenge | deadline | signature |
| 32 bytes  | 8 bytes  | 64 bytes  |
------------------------------------

Tuple Fields

0: [u8; 104]

Implementations

Source

impl ScChallenge

pub const SIZE: usize = 104usize