pub struct SetAttempts(pub u32);Tuple Fields
0: u32Trait Implementations
Sourceimpl Archive for SetAttemptswhere
u32: Archive,
impl Archive for SetAttemptswhere
u32: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSetAttempts
type Archived = ArchivedSetAttempts
The archived representation of this type. Read more
Sourcetype Resolver = SetAttemptsResolver
type Resolver = SetAttemptsResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for SetAttempts
impl BlockingArchive for SetAttempts
Sourceimpl Debug for SetAttempts
impl Debug for SetAttempts
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SetAttempts, __D> for Archived<SetAttempts>
impl<__D: Fallible + ?Sized> Deserialize<SetAttempts, __D> for Archived<SetAttempts>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SetAttempts, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SetAttempts, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SetAttempts
impl MessageId for SetAttempts
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SetAttemptswhere
u32: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SetAttemptswhere
u32: Serialize<__S>,