pub struct SetFirmwareTimestamp(pub FirmwareTimestamp);Tuple Fields
0: FirmwareTimestampTrait Implementations
Sourceimpl Archive for SetFirmwareTimestampwhere
FirmwareTimestamp: Archive,
impl Archive for SetFirmwareTimestampwhere
FirmwareTimestamp: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSetFirmwareTimestamp
type Archived = ArchivedSetFirmwareTimestamp
The archived representation of this type. Read more
Sourcetype Resolver = SetFirmwareTimestampResolver
type Resolver = SetFirmwareTimestampResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for SetFirmwareTimestamp
impl Debug for SetFirmwareTimestamp
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SetFirmwareTimestamp, __D> for Archived<SetFirmwareTimestamp>where
FirmwareTimestamp: Archive,
<FirmwareTimestamp as Archive>::Archived: Deserialize<FirmwareTimestamp, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SetFirmwareTimestamp, __D> for Archived<SetFirmwareTimestamp>where
FirmwareTimestamp: Archive,
<FirmwareTimestamp as Archive>::Archived: Deserialize<FirmwareTimestamp, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SetFirmwareTimestamp, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SetFirmwareTimestamp, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SetFirmwareTimestamp
impl MessageId for SetFirmwareTimestamp
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SetFirmwareTimestampwhere
FirmwareTimestamp: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SetFirmwareTimestampwhere
FirmwareTimestamp: Serialize<__S>,