pub struct SetSeedAndPin {
pub seed: Seed,
pub pin: RawPin,
pub pin_entry: PinEntryMode,
}Fields
seed: Seedpin: RawPinpin_entry: PinEntryModeTrait Implementations
Sourceimpl Archive for SetSeedAndPin
impl Archive for SetSeedAndPin
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSetSeedAndPin
type Archived = ArchivedSetSeedAndPin
The archived representation of this type. Read more
Sourcetype Resolver = SetSeedAndPinResolver
type Resolver = SetSeedAndPinResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for SetSeedAndPin
impl BlockingArchive for SetSeedAndPin
Sourceimpl Clone for SetSeedAndPin
impl Clone for SetSeedAndPin
Sourcefn clone(&self) -> SetSeedAndPin
fn clone(&self) -> SetSeedAndPin
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<__D: Fallible + ?Sized> Deserialize<SetSeedAndPin, __D> for Archived<SetSeedAndPin>where
Seed: Archive,
<Seed as Archive>::Archived: Deserialize<Seed, __D>,
RawPin: Archive,
<RawPin as Archive>::Archived: Deserialize<RawPin, __D>,
PinEntryMode: Archive,
<PinEntryMode as Archive>::Archived: Deserialize<PinEntryMode, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SetSeedAndPin, __D> for Archived<SetSeedAndPin>where
Seed: Archive,
<Seed as Archive>::Archived: Deserialize<Seed, __D>,
RawPin: Archive,
<RawPin as Archive>::Archived: Deserialize<RawPin, __D>,
PinEntryMode: Archive,
<PinEntryMode as Archive>::Archived: Deserialize<PinEntryMode, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SetSeedAndPin, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SetSeedAndPin, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SetSeedAndPin
impl MessageId for SetSeedAndPin
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SetSeedAndPin
impl<__S: Fallible + ?Sized> Serialize<__S> for SetSeedAndPin