pub struct SignWithSecurityCheckKey(pub [u8; 32]);Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl Archive for SignWithSecurityCheckKey
impl Archive for SignWithSecurityCheckKey
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSignWithSecurityCheckKey
type Archived = ArchivedSignWithSecurityCheckKey
The archived representation of this type. Read more
Sourcetype Resolver = SignWithSecurityCheckKeyResolver
type Resolver = SignWithSecurityCheckKeyResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for SignWithSecurityCheckKey
impl Debug for SignWithSecurityCheckKey
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SignWithSecurityCheckKey, __D> for Archived<SignWithSecurityCheckKey>
impl<__D: Fallible + ?Sized> Deserialize<SignWithSecurityCheckKey, __D> for Archived<SignWithSecurityCheckKey>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SignWithSecurityCheckKey, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SignWithSecurityCheckKey, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SignWithSecurityCheckKey
impl MessageId for SignWithSecurityCheckKey
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SignWithSecurityCheckKey
impl<__S: Fallible + ?Sized> Serialize<__S> for SignWithSecurityCheckKey