pub struct SubscribeDiskEncryptionKeysReady;Trait Implementations
Sourceimpl Archive for SubscribeDiskEncryptionKeysReady
impl Archive for SubscribeDiskEncryptionKeysReady
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSubscribeDiskEncryptionKeysReady
type Archived = ArchivedSubscribeDiskEncryptionKeysReady
The archived representation of this type. Read more
Sourcetype Resolver = SubscribeDiskEncryptionKeysReadyResolver
type Resolver = SubscribeDiskEncryptionKeysReadyResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SubscribeDiskEncryptionKeysReady, __D> for Archived<SubscribeDiskEncryptionKeysReady>
impl<__D: Fallible + ?Sized> Deserialize<SubscribeDiskEncryptionKeysReady, __D> for Archived<SubscribeDiskEncryptionKeysReady>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SubscribeDiskEncryptionKeysReady, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SubscribeDiskEncryptionKeysReady, <__D as Fallible>::Error>
Deserializes using the given deserializer