pub struct BluetoothChallengeSecret {
pub secret: [u8; 32],
pub sent: bool,
}Fields
secret: [u8; 32]sent: boolTrait Implementations
Sourceimpl Archive for BluetoothChallengeSecret
impl Archive for BluetoothChallengeSecret
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedBluetoothChallengeSecret
type Archived = ArchivedBluetoothChallengeSecret
The archived representation of this type. Read more
Sourcetype Resolver = BluetoothChallengeSecretResolver
type Resolver = BluetoothChallengeSecretResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for BluetoothChallengeSecret
impl Debug for BluetoothChallengeSecret
Sourceimpl<__D: Fallible + ?Sized> Deserialize<BluetoothChallengeSecret, __D> for Archived<BluetoothChallengeSecret>
impl<__D: Fallible + ?Sized> Deserialize<BluetoothChallengeSecret, __D> for Archived<BluetoothChallengeSecret>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<BluetoothChallengeSecret, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<BluetoothChallengeSecret, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for BluetoothChallengeSecret
impl<__S: Fallible + ?Sized> Serialize<__S> for BluetoothChallengeSecret