pub struct FirmwareTimestamp(pub [u8; 4]);Tuple Fields
0: [u8; 4]Trait Implementations
Sourceimpl Archive for FirmwareTimestamp
impl Archive for FirmwareTimestamp
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedFirmwareTimestamp
type Archived = ArchivedFirmwareTimestamp
The archived representation of this type. Read more
Sourcetype Resolver = FirmwareTimestampResolver
type Resolver = FirmwareTimestampResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for FirmwareTimestamp
impl Clone for FirmwareTimestamp
Sourcefn clone(&self) -> FirmwareTimestamp
fn clone(&self) -> FirmwareTimestamp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FirmwareTimestamp
impl Debug for FirmwareTimestamp
Sourceimpl Default for FirmwareTimestamp
impl Default for FirmwareTimestamp
Sourceimpl<__D: Fallible + ?Sized> Deserialize<FirmwareTimestamp, __D> for Archived<FirmwareTimestamp>
impl<__D: Fallible + ?Sized> Deserialize<FirmwareTimestamp, __D> for Archived<FirmwareTimestamp>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<FirmwareTimestamp, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<FirmwareTimestamp, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl From<FirmwareTimestamp> for u32
impl From<FirmwareTimestamp> for u32
Sourcefn from(ts: FirmwareTimestamp) -> u32
fn from(ts: FirmwareTimestamp) -> u32
Converts to this type from the input type.
Sourceimpl From<u32> for FirmwareTimestamp
impl From<u32> for FirmwareTimestamp
Sourcefn from(ts: u32) -> FirmwareTimestamp
fn from(ts: u32) -> FirmwareTimestamp
Converts to this type from the input type.
Sourceimpl PartialEq for FirmwareTimestamp
impl PartialEq for FirmwareTimestamp
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for FirmwareTimestamp
impl<__S: Fallible + ?Sized> Serialize<__S> for FirmwareTimestamp
impl Eq for FirmwareTimestamp
impl StructuralPartialEq for FirmwareTimestamp