pub struct Pin(pub [u8; 32]);Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl Archive for Pin
impl Archive for Pin
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedPin
type Archived = ArchivedPin
The archived representation of this type. Read more
Sourcetype Resolver = PinResolver
type Resolver = PinResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.