ScProof

Struct ScProof 

pub struct ScProof(pub [u8; 189]);
A message sent from the device to the server, serving to prove that the device knows the private key corresponding to the public key it claims to own. The message has the following binary format:

----------------------------------------------------------------------------------------
| challenge | deadline | device pubkey | device nonce | bootloader version | signature |
| 32 bytes  | 8 bytes  | 33 bytes      | 32 bytes     | 20 bytes           | 64 bytes  |
----------------------------------------------------------------------------------------

Tuple Fields

0: [u8; 189]

Implementations

Source

impl ScProof

pub const SIZE: usize = 189usize