KeyOS API Reference

Security

Struct Security 

pub struct Security<P: CheckedPermissions> { /* private fields */ }

Implementations

Source

impl<P: CheckedPermissions> Security<P>

pub fn set_seed_and_pin( &self, seed: Seed, pin: String, pin_entry: PinEntryMode, ) -> Result<(), PinError>

Permission: os/security / SetSeedAndPin

Permission group: none

Required signature: foundation

Approval: autoAllow

User does not need to be logged in. Use this when setting the seed and PIN for the first time.

pub fn change_pin( &self, raw_pin: String, seed: Option<Seed>, pin_entry: PinEntryMode, ) -> Result<(), PinError>

Permission: os/security / ChangePin

Permission group: none

Required signature: foundation

Approval: autoAllow

User must be logged in to set a new pin.

pub fn is_pin_set(&self) -> Result<bool, AccessDenied>

Permission: os/security / IsPinSet

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn get_pin_entry_mode(&self) -> PinEntryMode

Permission: os/security / GetPinEntryMode

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn log_in(&self, pin: String) -> Result<(), LoginFailed>

Permission: os/security / Login

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn log_out(&self)

Permission: os/security / Logout

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn logged_in(&self) -> bool

Permission: os/security / LoggedIn

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn attempts_remaining(&self) -> Result<u32, AccessDenied>

Permission: os/security / GetAttemptsRemaining

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn factory_reset_counter(&self) -> Result<u32, AccessDenied>

Permission: os/security / GetFactoryResetCounter

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn seed(&self) -> Result<Option<Seed>, AccessDenied>

Permission: os/security / GetSeed

Permission group: none

Required signature: foundation

Approval: autoAllow

Fetches the Seed from SE.

Returns
  • None if otp_key field of SECURAM is set to all zeros.
  • Some(seed) otherwise.
pub fn set_seed(&self, seed: Seed) -> Result<(), AccessDenied>

Permission: os/security / SetSeed

Permission group: none

Required signature: foundation

Approval: notUserGrantable

User must be logged in to change the seed. This is because a XOR operation will be performed between the seed and the PIN hash before storing it in the SE.

In case the user is setting the seed for the first time, use SetSeedAndPin instead.

pub fn app_seed(&self) -> Result<[u8; 32], AccessDenied>

Permission: os/security / GetAppSeed

Permission group: device-secrets.app-scoped-seed

Required signature: thirdParty

Approval: grantOnFirstUse

pub fn lockout( &self, lockout_options: LockoutOptions, ) -> Result<(), AccessDenied>

Permission: os/security / Lockout

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn sign_with_security_check_key( &self, data: [u8; 32], ) -> Result<[u8; 64], AccessDenied>

Permission: os/security / SignWithSecurityCheckKey

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn sign_with_fido_key( &self, data: [u8; 32], ) -> Result<[u8; 64], AccessDenied>

Permission: os/security / SignWithFidoKey

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn get_fido_pubkey(&self) -> Result<[u8; 64], AccessDenied>

Permission: os/security / GetFidoPubkey

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn security_words( &self, pin_prefix: &str, ) -> Result<[SecurityWord; 2], AccessDenied>

Permission: os/security / GetSecurityWords

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn firmware_timestamp(&self) -> Result<FirmwareTimestamp, AccessDenied>

Permission: os/security / GetFirmwareTimestamp

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn set_firmware_timestamp( &self, timestamp: FirmwareTimestamp, ) -> Result<(), AccessDenied>

Permission: os/security / SetFirmwareTimestamp

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn seed_fingerprint(&self) -> Result<[u8; 32], AccessDenied>

Permission: os/security / GetSeedFingerprint

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn fingerprint(&self, seed: &Seed) -> Result<[u8; 32], AccessDenied>

Permission: os/security / ComputeSeedFingerprint

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn os_version_info(&self) -> Result<Option<OsVersionInfo>, AccessDenied>

Permission: os/security / GetOsVersionInfo

Permission group: device-secrets.general-status

Required signature: thirdParty

Approval: autoAllow

pub fn bootloader_build_date(&self) -> Result<Option<u64>, AccessDenied>

Permission: os/security / GetBootloaderBuildDate

Permission group: device-secrets.general-status

Required signature: thirdParty

Approval: autoAllow

pub fn sc_challenge( &self, challenge: [u8; 104], ) -> Result<ScProof, ScChallengeError>

Permission: os/security / ScChallenge

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn device_id(&self) -> Result<DeviceId, GetDeviceIdError>

Permission: os/security / GetDeviceId

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn get_random(&self) -> Result<[u8; 32], AccessDenied>

Permission: os/security / GetRandom

Permission group: device-secrets.general-status

Required signature: thirdParty

Approval: autoAllow

pub fn keycard_authenticity_mac( &self, msg: [u8; 32], ) -> Result<[u8; 32], AccessDenied>

Permission: os/security / KeycardAuthenticityMac

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn get_pin(&self) -> String

Permission: os/security / GetPin

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn set_attempts_remaining(&self, attempts: u32) -> Result<(), SecurityError>

Permission: os/security / SetAttempts

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn bluetooth_challenge_secret(&self) -> BluetoothChallengeSecret

Permission: os/security / GetBluetoothChallengeSecret

Permission group: none

Required signature: foundation

Approval: notUserGrantable

Get the bluetooth HMAC challenge secret and whether it was shared with the BT chip already.

pub fn set_bluetooth_challenge_secret_sent(&self)

Permission: os/security / SetBluetoothCheckSecretSent

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn set_bluetooth_device_id(&self, device_id: [u8; 8])

Permission: os/security / SetBluetoothDeviceId

Permission group: none

Required signature: foundation

Approval: notUserGrantable

pub fn master_key_state(&self) -> MasterKeyState

Permission: os/security / GetMasterKeyState

Permission group: none

Required signature: foundation

Approval: autoAllow

pub fn subscribe_disk_encryption_keys_ready<SR>( &self, context: &mut ServerContext<SR>, )

Permission: os/security / SubscribeDiskEncryptionKeysReady

Permission group: none

Required signature: foundation

Approval: notUserGrantable

Subscribe to the DiskEncryptionKeysReady event. The event fires once, when the security server has written disk encryption keys into SECURAM. Subscribers that arrive after the event has already fired receive it immediately on subscription.