pub struct SecurityWord(pub usize);Tuple Fields
0: usizeTrait Implementations
Sourceimpl Archive for SecurityWordwhere
usize: Archive,
impl Archive for SecurityWordwhere
usize: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSecurityWord
type Archived = ArchivedSecurityWord
The archived representation of this type. Read more
Sourcetype Resolver = SecurityWordResolver
type Resolver = SecurityWordResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for SecurityWord
impl Debug for SecurityWord
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SecurityWord, __D> for Archived<SecurityWord>
impl<__D: Fallible + ?Sized> Deserialize<SecurityWord, __D> for Archived<SecurityWord>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SecurityWord, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SecurityWord, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl Display for SecurityWord
impl Display for SecurityWord
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SecurityWordwhere
usize: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SecurityWordwhere
usize: Serialize<__S>,