pub struct SetSeed(pub Seed);Tuple Fields
0: SeedTrait Implementations
Sourceimpl Archive for SetSeedwhere
Seed: Archive,
impl Archive for SetSeedwhere
Seed: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSetSeed
type Archived = ArchivedSetSeed
The archived representation of this type. Read more
Sourcetype Resolver = SetSeedResolver
type Resolver = SetSeedResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for SetSeed
impl BlockingArchive for SetSeed
Sourcetype Response = Result<(), AccessDenied>
type Response = Result<(), AccessDenied>
response type for this message
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SetSeed, __D> for Archived<SetSeed>
impl<__D: Fallible + ?Sized> Deserialize<SetSeed, __D> for Archived<SetSeed>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SetSeed, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SetSeed, <__D as Fallible>::Error>
Deserializes using the given deserializer