pub struct DeviceId(pub [u8; 32]);Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl Archive for DeviceIdwhere
[u8; 32]: Archive,
impl Archive for DeviceIdwhere
[u8; 32]: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDeviceId
type Archived = ArchivedDeviceId
The archived representation of this type. Read more
Sourcetype Resolver = DeviceIdResolver
type Resolver = DeviceIdResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<__D: Fallible + ?Sized> Deserialize<DeviceId, __D> for Archived<DeviceId>where
[u8; 32]: Archive,
<[u8; 32] as Archive>::Archived: Deserialize<[u8; 32], __D>,
impl<__D: Fallible + ?Sized> Deserialize<DeviceId, __D> for Archived<DeviceId>where
[u8; 32]: Archive,
<[u8; 32] as Archive>::Archived: Deserialize<[u8; 32], __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<DeviceId, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<DeviceId, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Copy for DeviceId
impl Eq for DeviceId
impl StructuralPartialEq for DeviceId