Security

Struct Security 

pub struct Security<P: CheckedPermissions> { /* private fields */ }

Implementations

Source

impl<P: CheckedPermissions> Security<P>

pub fn set_seed_and_pin( &self, seed: Seed, pin: String, pin_entry: PinEntryMode, ) -> Result<(), PinError>

Permission: os/security / SetSeedAndPin

Groups: device-secrets.owner-auth

Sender policy: static-server

Grant timing: policy-only

User does not need to be logged in. Use this when setting the seed and PIN for the first time.

pub fn change_pin( &self, raw_pin: String, seed: Option<Seed>, pin_entry: PinEntryMode, ) -> Result<(), PinError>

Permission: os/security / ChangePin

Groups: device-secrets.owner-auth

Sender policy: static-server

Grant timing: policy-only

User must be logged in to set a new pin.

pub fn is_pin_set(&self) -> Result<bool, AccessDenied>

Permission: os/security / IsPinSet

Groups: device-secrets.status

Sender policy: signed

Grant timing: install-review

pub fn get_pin_entry_mode(&self) -> PinEntryMode

Permission: os/security / GetPinEntryMode

Groups: device-secrets.status

Sender policy: signed

Grant timing: install-review

pub fn log_in(&self, pin: String) -> Result<(), LoginFailed>

Permission: os/security / Login

Groups: device-secrets.owner-auth

Sender policy: static-server

Grant timing: policy-only

pub fn log_out(&self)

Permission: os/security / Logout

Groups: device-secrets.owner-auth

Sender policy: static-server

Grant timing: policy-only

pub fn logged_in(&self) -> bool

Permission: os/security / LoggedIn

Groups: device-secrets.status

Sender policy: signed

Grant timing: install-review

pub fn attempts_remaining(&self) -> Result<u32, AccessDenied>

Permission: os/security / GetAttemptsRemaining

Groups: device-secrets.status

Sender policy: signed

Grant timing: install-review

pub fn factory_reset_counter(&self) -> Result<u32, AccessDenied>

Permission: os/security / GetFactoryResetCounter

Groups: device-secrets.status

Sender policy: signed

Grant timing: install-review

pub fn seed(&self) -> Result<Option<Seed>, AccessDenied>

Permission: os/security / GetSeed

Groups: device-secrets.master-seed

Sender policy: static-server

Grant timing: policy-only

Fetches the Seed from SE.

Returns
  • None if otp_key field of SECURAM is set to all zeros.
  • Some(seed) otherwise.
pub fn set_seed(&self, seed: Seed) -> Result<(), AccessDenied>

Permission: os/security / SetSeed

Groups: device-secrets.master-seed

Sender policy: static-server

Grant timing: policy-only

User must be logged in to change the seed. This is because a XOR operation will be performed between the seed and the PIN hash before storing it in the SE.

In case the user is setting the seed for the first time, use SetSeedAndPin instead.

pub fn app_seed(&self) -> Result<[u8; 32], AccessDenied>

Permission: os/security / GetAppSeed

Groups: device-secrets.app-scoped-seed

Sender policy: signed

Grant timing: install-review

pub fn lockout( &self, lockout_options: LockoutOptions, ) -> Result<(), AccessDenied>

Permission: os/security / Lockout

Groups: device-secrets.owner-auth

Sender policy: static-server

Grant timing: policy-only

pub fn sign_with_security_check_key( &self, data: [u8; 32], ) -> Result<[u8; 64], AccessDenied>

Permission: os/security / SignWithSecurityCheckKey

Groups: cryptography.secure-signing

Sender policy: static-server

Grant timing: policy-only

pub fn sign_with_fido_key( &self, data: [u8; 32], ) -> Result<[u8; 64], AccessDenied>

Permission: os/security / SignWithFidoKey

Groups: cryptography.secure-signing

Sender policy: static-server

Grant timing: policy-only

pub fn get_fido_pubkey(&self) -> Result<[u8; 64], AccessDenied>

Permission: os/security / GetFidoPubkey

Groups: cryptography.secure-signing

Sender policy: static-server

Grant timing: policy-only

pub fn security_words( &self, pin_prefix: &str, ) -> Result<[SecurityWord; 2], AccessDenied>

Permission: os/security / GetSecurityWords

Groups: device-secrets.owner-auth

Sender policy: static-server

Grant timing: policy-only

pub fn firmware_timestamp(&self) -> Result<FirmwareTimestamp, AccessDenied>

Permission: os/security / GetFirmwareTimestamp

Groups: device-secrets.firmware-timestamp

Sender policy: foundation-signed

Grant timing: policy-only

pub fn set_firmware_timestamp( &self, timestamp: FirmwareTimestamp, ) -> Result<(), AccessDenied>

Permission: os/security / SetFirmwareTimestamp

Groups: device-secrets.firmware-timestamp

Sender policy: foundation-signed

Grant timing: policy-only

pub fn seed_fingerprint(&self) -> Result<[u8; 32], AccessDenied>

Permission: os/security / GetSeedFingerprint

Groups: device-secrets.device-identity

Sender policy: signed

Grant timing: grant-on-first-use

pub fn fingerprint(&self, seed: &Seed) -> Result<[u8; 32], AccessDenied>

Permission: os/security / ComputeSeedFingerprint

Groups: device-secrets.device-identity

Sender policy: signed

Grant timing: grant-on-first-use

pub fn os_version_info(&self) -> Result<Option<OsVersionInfo>, AccessDenied>

Permission: os/security / GetOsVersionInfo

Groups: device-secrets.status

Sender policy: signed

Grant timing: install-review

pub fn bootloader_build_date(&self) -> Result<Option<u64>, AccessDenied>

Permission: os/security / GetBootloaderBuildDate

Groups: device-secrets.status

Sender policy: signed

Grant timing: install-review

pub fn sc_challenge( &self, challenge: [u8; 104], ) -> Result<ScProof, ScChallengeError>

Permission: os/security / ScChallenge

Groups: cryptography.secure-signing

Sender policy: static-server

Grant timing: policy-only

pub fn device_id(&self) -> Result<DeviceId, GetDeviceIdError>

Permission: os/security / GetDeviceId

Groups: device-secrets.device-identity

Sender policy: signed

Grant timing: grant-on-first-use

pub fn get_random(&self) -> Result<[u8; 32], AccessDenied>

Permission: os/security / GetRandom

Groups: device-secrets.status

Sender policy: signed

Grant timing: install-review

pub fn keycard_authenticity_mac( &self, msg: [u8; 32], ) -> Result<[u8; 32], AccessDenied>

Permission: os/security / KeycardAuthenticityMac

Groups: cryptography.secure-signing

Sender policy: static-server

Grant timing: policy-only

pub fn get_pin(&self) -> String

Permission: os/security / GetPin

Groups: device-secrets.owner-auth

Sender policy: static-server

Grant timing: policy-only

pub fn set_attempts_remaining(&self, attempts: u32) -> Result<(), SecurityError>

Permission: os/security / SetAttempts

Groups: device-secrets.admin-and-pairing-state

Sender policy: static-server

Grant timing: policy-only

pub fn bluetooth_challenge_secret(&self) -> BluetoothChallengeSecret

Permission: os/security / GetBluetoothChallengeSecret

Groups: device-secrets.admin-and-pairing-state

Sender policy: static-server

Grant timing: policy-only

Get the bluetooth HMAC challenge secret and whether it was shared with the BT chip already.

pub fn set_bluetooth_challenge_secret_sent(&self)

Permission: os/security / SetBluetoothCheckSecretSent

Groups: device-secrets.admin-and-pairing-state

Sender policy: static-server

Grant timing: policy-only

pub fn set_bluetooth_device_id(&self, device_id: [u8; 8])

Permission: os/security / SetBluetoothDeviceId

Groups: device-secrets.admin-and-pairing-state

Sender policy: static-server

Grant timing: policy-only

pub fn master_key_state(&self) -> MasterKeyState

Permission: os/security / GetMasterKeyState

Groups: device-secrets.status

Sender policy: signed

Grant timing: install-review

pub fn subscribe_disk_encryption_keys_ready<SR>( &self, context: &mut ServerContext<SR>, )

Permission: os/security / SubscribeDiskEncryptionKeysReady

Groups: TBD

Sender policy: TBD

Grant timing: TBD

Subscribe to the DiskEncryptionKeysReady event. The event fires once, when the security server has written disk encryption keys into SECURAM. Subscribers that arrive after the event has already fired receive it immediately on subscription.